pro read_hdf_L2_CLDPRF,path,FNAME				;RELEASE VERSION 2.4
;
;This is a simple read program for the CALIPSO Lidar Level 2
; Data Products, including assignments to variables contained in the
; Lidar Level 2 5km Cloud Profile Common (L2_CLDPRF_COMMON.pro)
; The user can comment out any assignments not required for their application.
; This Reader Version 2.4 corresponds to the Data Products Catalog Release 2.4.
; The DP Catalog is available on the CALIPSO public website:
;		http://www-calipso.larc.nasa.gov/resources/project_documentation.php
; This reader corresponds to DPC Tables 40 and 41.
;
; There are 2 string inputs to this program:
;   1) the path (i.e. 'C:\') containing the data
;   2) the filename of the Lidar Level 2 5km Cloud Profile HDF file to be read.
;
; Also provided is a corresponding Checkit_CLDPRF program to verify that all variables
;   have been read and assigned. It is called at the end of this program.
;
;
; August 16, 2007	PLL (Science Systems & Applications, Inc.)  Initial Release
; December 3, 2007	PLL (Science Systems & Applications, Inc.)  Data Release
;

@L2_CLDPRF_COMMON

dsets=0
attrs=0

print,'opening ',path + '\' + FNAME

fid=hdf_open(path + '\' + FNAME,/read)
SDinterface_id = HDF_SD_START( path + '\' + FNAME , /READ  )

HDF_SD_Fileinfo,SDinterface_id,dsets,attrs

; Retrieve the names of the sds variables
for k=0,dsets-1 do begin
    sds_id=HDF_SD_SELECT(SDinterface_id,k)
    HDF_SD_GETINFO,sds_id,name=var,dims=dimx,format=formx,hdf_type=hdft,unit=unitx;,range=xrng


;TABLE 41 PARAMETERS


if var eq 'Latitude_Start' then HDF_SD_GETDATA,sds_id,CP_START_LAT
if var eq 'Latitude_Stop' then HDF_SD_GETDATA,sds_id,CP_STOP_LAT
if var eq 'Longitude_Start' then HDF_SD_GETDATA,sds_id,CP_START_LON
if var eq 'Longitude_Stop' then HDF_SD_GETDATA,sds_id,CP_STOP_LON
if var eq 'Profile_Time_Start' then HDF_SD_GETDATA,sds_id,CP_START_TIME
if var eq 'Profile_Time_Stop' then HDF_SD_GETDATA,sds_id,CP_STOP_TIME
if var eq 'Profile_UTC_Start' then HDF_SD_GETDATA,sds_id, CP_UTC_START
if var eq 'Profile_UTC_Stop' then HDF_SD_GETDATA,sds_id, CP_UTC_STOP
if var eq 'Tropopause_Height' then HDF_SD_GETDATA,sds_id, CP_TROP_HEIGHT
if var eq 'Tropopause_Temperature' then HDF_SD_GETDATA,sds_id, CP_TROP_TEMP
if var eq 'Temperature' then HDF_SD_GETDATA,sds_id,CP_TEMP
if var eq 'Pressure' then HDF_SD_GETDATA,sds_id,CP_PRESS
if var eq 'Molecular_Number_Density' then HDF_SD_GETDATA,sds_id,CP_MOL_NUM_DEN
if var eq 'Relative_Humidity' then HDF_SD_GETDATA,sds_id,CP_REL_HUM
if var eq 'Profile_QA_Flag' then HDF_SD_GETDATA,sds_id,CP_QA_FLAG
if var eq 'Surface_Elevation_Statistics' then HDF_SD_GETDATA,sds_id,CP_SURF_ELEV_STAT
if var eq 'Samples_Averaged' then HDF_SD_GETDATA,sds_id,CP_SAMP_AVG
if var eq 'Cloud_Layer_Fraction' then HDF_SD_GETDATA,sds_id,CP_CLD_LAY_FRAC
if var eq 'Total_Backscatter_Coefficient_532' then HDF_SD_GETDATA,sds_id,CP_TOT_BKS_COEF
if var eq 'Total_Backscatter_Coefficient_Uncertainty_532' then HDF_SD_GETDATA,sds_id,CP_TOT_BKS_COEF_UNC
if var eq 'Perpendicular_Backscatter_Coefficient_532' then HDF_SD_GETDATA,sds_id,CP_PER_BKS_COEF
if var eq 'Perpendicular_Backscatter_Coefficient_Uncertainty_532' then HDF_SD_GETDATA,sds_id,CP_PER_BKS_COEF_UNC
if var eq 'Particulate_Depolarization_Ratio_Profile_532' then HDF_SD_GETDATA,sds_id,CP_PART_DPR_PROF
if var eq 'Particulate_Depolarization_Ratio_Uncertainty_532' then HDF_SD_GETDATA,sds_id,CP_PART_DPR_UNC
if var eq 'Extinction_Coefficient_532' then HDF_SD_GETDATA,sds_id,CP_EXT_COEF
if var eq 'Extinction_Coefficient_Uncertainty_532' then HDF_SD_GETDATA,sds_id,CP_EXT_COEF_UNC
if var eq 'Cloud_Multiple_Scattering_Profile_532' then HDF_SD_GETDATA,sds_id,CP_CLD_MULT_SCAT
if var eq 'Cloud_Multiple_Scattering_Uncertainty_532' then HDF_SD_GETDATA,sds_id,CP_CLD_MULT_SCAT_UNC
if var eq 'Ice_Water_Content_Profile' then HDF_SD_GETDATA,sds_id,CP_ICEWATR_CNTNT
if var eq 'Ice_Water_Content_Profile_Uncertainty' then HDF_SD_GETDATA,sds_id,CP_ICEWATR_CNTNT_UNC


HDF_SD_ENDACCESS,sds_id

endfor

HDF_SD_END,SDinterface_id

;Retrieve the Vdata information
vds_id = HDF_VD_LONE(fid)
vdata_id=HDF_VD_ATTACH(fid,vds_id,/read)

HDF_VD_GET,vdata_id,name=var,count=cnt,fields=flds,size=sze,nfields=nflds


;TABLE 40 PARAMETERS

nrec = HDF_VD_READ(vdata_id,CP_PROD_ID,fields='Product_ID')
nrec = HDF_VD_READ(vdata_id,CP_DAT_TIM_START,fields='Date_Time_at_Granule_Start')
nrec = HDF_VD_READ(vdata_id,CP_DAT_TIM_END,fields='Date_Time_at_Granule_End')
nrec = HDF_VD_READ(vdata_id,CP_DAT_TIM_PROD,fields='Date_Time_of_Production')
nrec = HDF_VD_READ(vdata_id,CP_NUM_GOOD_PROF,fields='Number_of_Good_Profiles')
nrec = HDF_VD_READ(vdata_id,CP_NUM_BAD_PROF,fields='Number_of_Bad_Profiles')
nrec = HDF_VD_READ(vdata_id,CP_INIT_SUBSAT_LAT,fields='Initial_Subsatellite_Latitude')
nrec = HDF_VD_READ(vdata_id,CP_INIT_SUBSAT_LON,fields='Initial_Subsatellite_Longitude')
nrec = HDF_VD_READ(vdata_id,CP_FINAL_SUBSAT_LAT,fields='Final_Subsatellite_Latitude')
nrec = HDF_VD_READ(vdata_id,CP_FINAL_SUBSAT_LON,fields='Final_Subsatellite_Longitude')
nrec = HDF_VD_READ(vdata_id,CP_RAY_EXT_532,fields='Rayleigh_Extinction_Cross-section_532')
nrec = HDF_VD_READ(vdata_id,CP_RAY_EXT_1064,fields='Rayleigh_Extinction_Cross-section_1064')
nrec = HDF_VD_READ(vdata_id,CP_RAY_BKS_532,fields='Rayleigh_Backscatter_Cross-section_532')
nrec = HDF_VD_READ(vdata_id,CP_RAY_BKS_1064,fields='Rayleigh_Backscatter_Cross-section_1064')
nrec = HDF_VD_READ(vdata_id,CP_L1_PROD_DAT_TIM,fields='Lidar_L1_Production_Date_Time')
nrec = HDF_VD_READ(vdata_id,CP_LID_ALTS,fields='Lidar_Data_Altitudes')
nrec = HDF_VD_READ(vdata_id,CP_GEOS_VER,fields='GEOS_Version')
nrec = HDF_VD_READ(vdata_id,CP_PROD_SCRPT,fields='Production_Script')


HDF_VD_DETACH,vdata_id

HDF_CLOSE,fid

@Checkit_CLDPRF

;close,/all

;stop

end
